import { useState, useEffect } from 'react';

/**
 * Use Last.fm
 * @param username The username of the last.fm user to track
 * @param token Your API token
 * @param interval Optional, this is the internal between each request
 * @param imageSize The size of the image
 */

var useLastFM = function useLastFM(username, token, interval, imageSize) {
  if (interval === void 0) {
    interval = 15 * 1000;
  }

  if (imageSize === void 0) {
    imageSize = 'extralarge';
  }

  var _useState = useState('connecting'),
      track = _useState[0],
      setTrack = _useState[1];

  var endpoint = "//ws.audioscrobbler.com/2.0/?method=user.getrecenttracks&user=" + username + "&api_key=" + token + "&format=json&limit=1";
  useEffect(function () {
    var run = function run() {
      try {
        if (process.env.NODE_ENV !== "production") {
          console.log('[LAST.FM] Fetching');
        }

        return Promise.resolve(fetch(endpoint)).then(function (request) {
          return Promise.resolve(request.json()).then(function (body) {
            var _lastSong$Attr, _image$Text;

            var lastSong = body.recenttracks.track[0];

            if (!((_lastSong$Attr = lastSong['@attr']) === null || _lastSong$Attr === void 0 ? void 0 : _lastSong$Attr.nowplaying)) {
              return 'idle';
            }

            var image = lastSong.image.find(function (i) {
              return i.size === imageSize;
            });
            return {
              name: lastSong.name,
              artist: lastSong.artist['#text'],
              art: (_image$Text = image === null || image === void 0 ? void 0 : image['#text']) !== null && _image$Text !== void 0 ? _image$Text : lastSong.image[0]['#text'],
              album: lastSong.album['#text']
            };
          });
        });
      } catch (e) {
        return Promise.reject(e);
      }
    };

    var execute = function execute() {
      return run().then(setTrack);
    };

    if (process.env.NODE_ENV !== "production") {
      execute().then(function () {
        return console.log('[LAST.FM] Connected');
      });
    } else {
      execute();
    }

    var loop = setInterval(execute, interval);
    return function () {
      return clearInterval(loop);
    };
  }, [endpoint, interval, imageSize]);
  return track;
};

export { useLastFM };
//# sourceMappingURL=use-last-fm.esm.js.map
